from astropy.io import ascii
from astropy.table import Table
import matplotlib.pyplot as plt 
import sys,os
import numpy as np
import upsilon
rf_model = upsilon.load_rf_model()
def fold(mag,err,mjd,period):
    foldmjd=mjd/period
    foldmjd=foldmjd % 1
    mag=mag    
    return foldmjd,mag,err
def get_period(filename,plot_figure=True):
    outfile=os.path.splitext(filename)[0]+'.png'
    #LC=ascii.read(filename)
    LC=Table.read(filename,names=('JD','Mag','MagErr'),format='ascii.fast_no_header')
    
    jd=LC['JD']
    mag=LC['Mag']
    magerr=LC['MagErr']
    e_features = upsilon.ExtractFeatures(jd, mag,magerr)
    e_features.run()
    features = e_features.get_features()
    label, probability, flag = upsilon.predict(rf_model, features)
    if (flag==1 or probability>0.6) and ('EB' in label or 'EA' in label or 'EC' in label):
        period=2*features['period']    
    else:
        period=features['period']
    print('Amplitude %.6f'%features['amplitude'])
    print('Period %.5f'%features['period'])
    print('Period_SNR %.2f'%features['period_SNR'])
    fjd,fmag,fmagerr=fold(mag,0.01*mag,jd,2*period)
    print(label,probability,flag)
    if plot_figure==True:
        plt.plot(fjd,fmag,'r.')
        
        if flag==1 or probability>0.6:
            plt.title(filename+' Type: '+label+' probability: %.2f'%probability)
        else:
            plt.title(filename)
        plt.xlabel('Period %.4f SNR: %.2f'%(period,features['period_SNR']))
        plt.savefig(outfile)
        plt.close()
filename=sys.argv[1]
get_period(filename,plot_figure=True)
